@@ -6,6 +6,7 @@
 
 void cstmp(MP_INT *, unsigned char *, unsigned int);
 void mptcs(unsigned char *,unsigned int,MP_INT *);
+void modinv(MP_INT *, MP_INT *, MP_INT *);
 
 #ifndef STAND
 int genkey(MP_INT *, MP_INT *,  MP_INT *, unsigned int);
@@ -26,9 +27,9 @@ void v_p1_n(MP_INT *,MP_INT *, MP_INT *, MP_INT *);
 void halfluc(MP_INT *, MP_INT *, MP_INT *, MP_INT *, MP_INT *, MP_INT *);
 void halfrsa(MP_INT *, MP_INT *, MP_INT *, MP_INT *, MP_INT *, MP_INT *);
 
-/* the following provide room for 2048 bit numbers */
-#define MAXMPSIZE 64
-#define MAXC (MAXMPSIZE * 4)
+/* the following provide room for 4096 bit numbers */
+#define MAXMPSIZE 128
+#define MAXC (MAXMPSIZE * sizeof(unsigned long))
 
 #define RSA 1
 #define LUC 2
