@@ -2,7 +2,7 @@ void write_number(FILE *,MP_INT *);
 int read_number(FILE *,MP_INT *);
 int write_string(FILE *,unsigned char *);
 int read_string(FILE *,unsigned char *);
-int desfile(FILE *, FILE *, unsigned char *, unsigned char *, int);
+int scramble(FILE *, FILE *, unsigned char *, unsigned char *, int);
 void write_numberx(FILE *,MP_INT *,unsigned char *,unsigned char *);
 int read_numberx(FILE *,MP_INT *, unsigned char *, unsigned char *);
 void mdfile(FILE *, unsigned char *);
